==> org.eclipse.riena.example.client.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/example/client/controllers/ContextMenuSubModuleController.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.example.client.controllers;

import org.eclipse.core.databinding.observable.list.WritableList;

import org.eclipse.riena.beans.common.Person;
import org.eclipse.riena.beans.common.PersonFactory;
import org.eclipse.riena.example.client.views.ContextMenuSubModuleView;
import org.eclipse.riena.navigation.ISubModuleNode;
import org.eclipse.riena.navigation.ui.controllers.SubModuleController;
import org.eclipse.riena.ui.ridgets.IActionListener;
import org.eclipse.riena.ui.ridgets.IMenuItemRidget;
import org.eclipse.riena.ui.ridgets.ITableRidget;
import org.eclipse.riena.ui.ridgets.ITextRidget;
import org.eclipse.riena.ui.ridgets.IToggleButtonRidget;

/**
 * Controller for the {@link ContextMenuSubModuleView} example.
 */
public class ContextMenuSubModuleController extends SubModuleController {

	public ContextMenuSubModuleController() {
		this(null);
	}

	public ContextMenuSubModuleController(ISubModuleNode navigationNode) {
		super(navigationNode);
	}

	/**
	 * Binds and updates the ridgets.
	 */
	@Override
	public void configureRidgets() {
		final ITextRidget textField = (ITextRidget) getRidget("textField"); //$NON-NLS-1$
		textField.updateFromModel();

		final IMenuItemRidget textClear = (IMenuItemRidget) getRidget("textClear"); //$NON-NLS-1$
		textClear.addListener(new IActionListener() {
			public void callback() {
				textField.setText(""); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemFoo = (IMenuItemRidget) getRidget("itemFoo"); //$NON-NLS-1$
		itemFoo.addListener(new IActionListener() {
			public void callback() {
				textField.setText("foo"); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemBar = (IMenuItemRidget) getRidget("itemBar"); //$NON-NLS-1$
		itemBar.addListener(new IActionListener() {
			public void callback() {
				textField.setText("bar"); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemBaz = (IMenuItemRidget) getRidget("itemBaz"); //$NON-NLS-1$
		itemBaz.addListener(new IActionListener() {
			public void callback() {
				textField.setText("baz"); //$NON-NLS-1$
			}
		});

		final IToggleButtonRidget markerButton = (IToggleButtonRidget) getRidget("markerButton"); //$NON-NLS-1$
		markerButton.addListener(new IActionListener() {
			public void callback() {
				boolean state = markerButton.isSelected();
				textClear.setVisible(!state);
			}
		});

		final WritableList personList = new WritableList(PersonFactory.createPersonList(), Person.class);
		final ITableRidget table = (ITableRidget) getRidget("table"); //$NON-NLS-1$

		String[] columnPropertyNames = { Person.PROPERTY_FIRSTNAME, Person.PROPERTY_LASTNAME };
		String[] columnHeaders = { "FirstName", "LastName" }; //$NON-NLS-1$ //$NON-NLS-2$ 
		table.bindToModel(new WritableList(personList, Person.class), Person.class, columnPropertyNames, columnHeaders);
		table.updateFromModel();

		IMenuItemRidget tableRemoveSelected = (IMenuItemRidget) getRidget("tableRemove"); //$NON-NLS-1$
		tableRemoveSelected.addListener(new IActionListener() {
			public void callback() {
				int sel = table.getSelectionIndex();
				if (sel > -1) {
					personList.remove(sel);
					table.updateFromModel();
				}
			}
		});
	}
}

==> org.eclipse.riena.example.client.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/example/client/controllers/ContextMenuSubModuleController.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.example.client.controllers;

import org.eclipse.core.databinding.observable.list.WritableList;

import org.eclipse.riena.beans.common.Person;
import org.eclipse.riena.beans.common.PersonFactory;
import org.eclipse.riena.example.client.views.ContextMenuSubModuleView;
import org.eclipse.riena.navigation.ISubModuleNode;
import org.eclipse.riena.navigation.ui.controllers.SubModuleController;
import org.eclipse.riena.ui.ridgets.IActionListener;
import org.eclipse.riena.ui.ridgets.IMenuItemRidget;
import org.eclipse.riena.ui.ridgets.ITableRidget;
import org.eclipse.riena.ui.ridgets.ITextRidget;
import org.eclipse.riena.ui.ridgets.IToggleButtonRidget;

/**
 * Controller for the {@link ContextMenuSubModuleView} example.
 */
public class ContextMenuSubModuleController extends SubModuleController {

	public ContextMenuSubModuleController() {
		this(null);
	}

	public ContextMenuSubModuleController(final ISubModuleNode navigationNode) {
		super(navigationNode);
	}

	/**
	 * Binds and updates the ridgets.
	 */
	@Override
	public void configureRidgets() {
		final ITextRidget textField = getRidget("textField"); //$NON-NLS-1$
		textField.updateFromModel();

		final IMenuItemRidget textClear = getRidget("textClear"); //$NON-NLS-1$
		textClear.addListener(new IActionListener() {
			public void callback() {
				textField.setText(""); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemFoo = getRidget("itemFoo"); //$NON-NLS-1$
		itemFoo.addListener(new IActionListener() {
			public void callback() {
				textField.setText("foo"); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemBar = getRidget("itemBar"); //$NON-NLS-1$
		itemBar.addListener(new IActionListener() {
			public void callback() {
				textField.setText("bar"); //$NON-NLS-1$
			}
		});

		final IMenuItemRidget itemBaz = getRidget("itemBaz"); //$NON-NLS-1$
		itemBaz.addListener(new IActionListener() {
			public void callback() {
				textField.setText("baz"); //$NON-NLS-1$
			}
		});

		final IToggleButtonRidget markerButton = getRidget("markerButton"); //$NON-NLS-1$
		markerButton.addListener(new IActionListener() {
			public void callback() {
				final boolean state = markerButton.isSelected();
				textClear.setVisible(!state);
			}
		});

		final WritableList personList = new WritableList(PersonFactory.createPersonList(), Person.class);
		final ITableRidget table = getRidget("table"); //$NON-NLS-1$

		final String[] columnPropertyNames = { Person.PROPERTY_FIRSTNAME, Person.PROPERTY_LASTNAME };
		final String[] columnHeaders = { "FirstName", "LastName" }; //$NON-NLS-1$ //$NON-NLS-2$ 
		table.bindToModel(new WritableList(personList, Person.class), Person.class, columnPropertyNames, columnHeaders);
		table.updateFromModel();

		final IMenuItemRidget tableRemoveSelected = getRidget("tableRemove"); //$NON-NLS-1$
		tableRemoveSelected.addListener(new IActionListener() {
			public void callback() {
				final int sel = table.getSelectionIndex();
				if (sel > -1) {
					personList.remove(sel);
					table.updateFromModel();
				}
			}
		});
	}
}
